import { Box, Button, TextField } from '@suid/material';
import { Component, createEffect, createSignal, Show } from 'solid-js';
import Dialog from '../dialog';

interface props {}

const [invitation, setInvitation] = createSignal<any>(false);

export const searchInvitation = () => {
  const hash = location.hash;
  console.log({ caller: 'Invitation / searchInvitation', hash });

  if (hash.length > 1) {
    try {
      const payload = hash.slice(1);
      const decoded = atob(payload);
      const url = new URL(decoded);
      fetch(url)
        .then((response) => response.json())
        .then((data) => {
          setInvitation({ url, data });
          console.log({
            caller: 'Invitation / searchInvitation',
            hash,
            invitation: invitation(),
          });
        });
    } catch {
      console.warn({
        caller: 'Invitation / searchInvitation',
        hash,
        message: 'Hash is not a base64 encoded URL',
      });
    }
  }
};

const Invitation: Component<props> = (props) => {
  createEffect(() => {
    console.log({
      caller: 'Invitation / createEffect',
      invitation: invitation(),
    });
  });

  const closeHandler = () => {};
  const submitHandler = async () => {
    try {
      const response = await fetch(
        `${invitation().url.href}/${invitation().code}`
      );
      const codeData = await response.json();
      setInvitation({ ...invitation(), codeData });
    } catch (error) {}
  };

  const codeChangeHandler = (event: any) => {
    setInvitation({ ...invitation(), code: event.target.value });
  };

  return (
    <Dialog
      open={!!invitation()}
      fullScreen={false}
      closeHandler={closeHandler}
      title='Invitation'
    >
      <Box
        component='form'
        sx={{
          width: '100%',
          '& .MuiTextField-root': { m: 1, width: '100%' },
          paddingTop: '5px',
        }}
        noValidate
        autoComplete='off'
      >
        <p>
          Pour configurer cette application en tant que "{invitation().data.id}
          ", copier le code qui vous a été envoyé par mail à l'adresse "
          {invitation().data.mail}" :{' '}
        </p>
        <TextField
          required
          label='Code'
          type='number'
          onChange={codeChangeHandler}
        />
        <Button variant='contained' onClick={submitHandler}>
          OK
        </Button>
      </Box>
    </Dialog>
  );
};

export default Invitation;
