import { Component, createEffect, createSignal, onCleanup } from 'solid-js';

import VectorSource from 'ol/source/Vector';
import GeoJSON from 'ol/format/GeoJSON';
import {
  createCachedSignal,
  destroyCachedSignal,
} from '../../workers/cached-signals';
import { fromLonLat } from 'ol/proj';

interface Props {
  rteId: string;
  vectorSources: VectorSource[];
  context: any;
}

export const Rte: Component<Props> = ({ vectorSources, rteId, context }) => {
  const params = {
    id: rteId,
    method: 'getRte',
  };
  const rte = createCachedSignal(params);

  onCleanup(() => {
    console.log({
      caller: 'Rte / onCleanup',
      rteId,
      rte: rte(),
      params,
    });

    destroyCachedSignal(params);
  });

  createEffect(() => {
    console.log({ caller: 'Rte', vectorSources, rteId, rte: rte() });

    if (rte() && rte().rtept && rte().rtept.length > 0) {
      let geo: any = {
        type: 'FeatureCollection',
        features: [
          {
            type: 'Feature',
            geometry: {
              type: 'Point',
              coordinates: fromLonLat([
                rte().rtept[0].$.lon,
                rte().rtept[0].$.lat,
              ]),
            },
            properties: {
              type: 'rte-start',
              id: rteId,
              context: { ...context, rte, rteId },
            },
            id: `${rteId}/start`,
          },
          {
            type: 'Feature',
            geometry: {
              type: 'LineString',
              coordinates: rte().rtept.map((rtept: any) =>
                fromLonLat([rtept.$.lon, rtept.$.lat])
              ),
            },
            properties: {
              type: 'rte',
              id: rteId,
              context: { ...context, rte, rteId },
            },
            id: rteId,
          },
          {
            type: 'Feature',
            geometry: {
              type: 'Point',
              coordinates: fromLonLat([
                rte().rtept.at(-1).$.lon,
                rte().rtept.at(-1).$.lat,
              ]),
            },
            properties: {
              type: 'rte-finish',
              id: rteId,
              context: { ...context, rte, rteId },
            },
            id: `${rteId}/end`,
          },
        ],
      };

      const features = new GeoJSON().readFeatures(geo);
      console.log({ caller: 'Rte', features });
      [`${rteId}/start`, rteId, `${rteId}/end`].forEach((id) => {
        const feature = vectorSources[0].getFeatureById(id);
        if (feature) {
          vectorSources[0].removeFeature(feature);
        }
      });
      vectorSources[0].addFeatures(features);
    }
  });

  return <></>;
};

export default Rte;
